@@ -71,12 +71,16 @@
 #' plot(ggrf)
 #' 
 #' }
-#' @importFrom reshape2 melt
+#' @importFrom tidyr gather
 #' @importFrom ggplot2 ggplot aes_string geom_step geom_ribbon labs geom_point geom_smooth geom_jitter geom_boxplot theme element_blank
 ### error rate plot
 plot.gg_rfsrc<- function(x, ...){
   obj <- x
   
+  # Initialize variables for gather statement... to silence R CMD CHECK
+  #!TODO must be a better way to do this.?select
+  variable <- value <- y <- ptid <- cens <- NA
+  
   ## rfsrc places the class in position 1.
   if(class(obj)[1] == "rfsrc") obj<- gg_rfsrc(obj, ...)
   
@@ -87,11 +91,11 @@ plot.gg_rfsrc<- function(x, ...){
       gDta <- ggplot(obj)+
         geom_jitter(aes_string(x=1, y=colnames(obj)[1],
                                color=colnames(obj)[2],
-                               shape=colnames(obj)[2]), alpha=.5)+
+                               shape=colnames(obj)[2]), ...)+
         geom_boxplot(aes_string(x=1, y=colnames(obj)[1]),
-                     outlier.colour = "transparent", fill="transparent", notch = TRUE)
+                     outlier.colour = "transparent", fill="transparent", notch = TRUE, ...)
     }else{
-      mlt <- melt(obj, id.vars = "y")
+      mlt <- obj %>% gather(variable, value, -y)
       gDta <- ggplot(mlt, aes_string(x="variable",y="value"))+
         geom_jitter(aes_string(color="y",shape="y"), alpha=.5)
     }
@@ -99,31 +103,31 @@ plot.gg_rfsrc<- function(x, ...){
   }else if(inherits(obj,"surv")){
     if(inherits(obj,"survSE")){
       # Summarized survival plot for the group...
-      obj.t <-  melt(select(obj, time, median, mean), id.vars="time")
+      obj.t <-  select(obj, time, median, mean)%>% gather(variable, value,-time)
       
       gDta <- ggplot(obj.t)+
         geom_ribbon(aes_string(x="time", ymin="lower", ymax="upper"), 
-                    alpha=.25, data=obj)+
-        geom_step(aes_string(x="time", y="value", color="variable"))
+                    data=obj, ...)+
+        geom_step(aes_string(x="time", y="value", color="variable"), ...)
       
     }else{
-      dta <- melt(obj, id.vars = c("ptid", "cens"))
+      dta <- obj %>% gather(variable, value, -ptid,-cens)
       dta$variable <- as.numeric(as.character(dta$variable))
       dta$ptid <- factor(dta$ptid)
       
       # Lines by observation
       gDta <- ggplot(dta)+
         geom_step(aes_string(x="variable", y="value", col="cens", by="ptid"), 
-                  alpha=.3, size=.1)
+                  ...)
     }
     
     gDta<-gDta  +
       labs(x="time (years)", y="OOB Survival (%)")
   }else if(inherits(obj, "regr")){
     gDta <- ggplot(obj)+
-      geom_jitter(aes_string(x=1, y="yhat"), alpha=.5)+
+      geom_jitter(aes_string(x=1, y="yhat"), ...)+
       geom_boxplot(aes_string(x=1, y="yhat"),
-                   outlier.colour = "transparent", fill="transparent", notch = TRUE)+
+                   outlier.colour = "transparent", fill="transparent", notch = TRUE, ...)+
       labs(y="Predicted Value", x=colnames(obj)[2])+
       theme(axis.ticks = element_blank(), axis.text.x = element_blank())
   }else{
