@@ -34,19 +34,39 @@
 #' data(iris_vs, package="ggRandomForests")
 #' 
 #' # Get a data.frame containing minimaldepth measures
-#' ggrf.obj<- gg_minimal_depth(iris_vs)
-#' print(ggrf.obj)
+#' ggrf_md<- gg_minimal_depth(iris_vs)
+#' print(ggrf_md)
+#' 
+#' ## ------------------------------------------------------------
+#' ## regression example
+#' ## ------------------------------------------------------------
+#' # ... or load a cached randomForestSRC object
+#' data(airq_vs, package="ggRandomForests")
+#' 
+#' # Get a data.frame containing minimaldepth measures
+#' ggrf_md<- gg_minimal_depth(airq_vs)
+#' print(ggrf_md)
+#' 
+#' # To nicely print a rfsrc::var.select output... 
+#' print.gg_minimal_depth(airq_vs)
+#' 
 #' 
 print.gg_minimal_depth <- function(x, ...){
   object <- x
+  
+  # If object is not a gg_minimal_depth object, check if it is the output
+  # from rfsrc::var.select
+  if(!inherits(x, "gg_minimal_depth"))
+    object <- gg_minimal_depth(x)
+  
   cat("-----------------------------------------------------------\n")
   cat("gg_minimal_depth\n")
   cat("model size         :", object$modelsize, "\n")
   cat("depth threshold    :", round(object$md.obj$threshold, 4),  "\n")
   cat("\n")
-  cat("PE :\n")
+  cat("PE :")
   print(round(object$err.rate, 3))
-  
+
   cat("-----------------------------------------------------------\n")
   cat("\n")
   cat("Top variables:\n")
